@@ -17,11 +17,11 @@ use WWW::Search::Scrape::Bing;
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 =head1 SYNOPSIS
@@ -111,6 +111,9 @@ sub search (%) {
     }
 
     if (lc $q->{engine} eq 'google') {
+	if ($q->{geo_location}) {
+	     $WWW::Search::Scrape::Google::geo_location = $q->{geo_location};
+	}
         if ($q->{frontpage}) {
             $WWW::Search::Scrape::Google::frontpage = $q->{frontpage};
         }
@@ -127,15 +130,16 @@ sub search (%) {
 
 =head1 AUTHOR
 
-Quan Sun, C<< <cfk.quan at gmail.com> >>
+Quan Sun, C<< <qsun at pardiff.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-www-search-scrape at rt.cpan.org>, or C<cfk.quan@gmail.com>, or through
+Please report any bugs or feature requests to C<bug-www-search-scrape at rt.cpan.org>, or C<qsun@pardiff.com>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Search-Scrape>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 
+L<http://github.com/qsun/WWW-Search-Scrape>
 
 
 =head1 SUPPORT
